pub struct TimeOfDayReturnProfileOutput {
pub bins: Vec<f64>,
}Expand description
Time-of-Day Return Profile output: the per-bucket mean return.
bins[i] is the mean simple return of all bars whose local time-of-day fell
in bucket i, where bucket i spans the minutes
[i * 1440 / bins.len(), (i + 1) * 1440 / bins.len()). Empty buckets read
0.0.
Fields
bins: Vec<f64>Per-bucket mean return, earliest bucket first. Length equals buckets.